### 免费调用的chatgpt工具包
#### 功能描述
* 无需token直接可以使用的chatgpt工具包 
                 
#### pip安装
```shell
pip install freechatgpt
```

##### 1.获取问题答案
```
    r = FreeChatgpt.ask(question='帮我创作一个广告视频宣传华为mate手机卖点？')
    print(r)
```
##### 2.其它问题
```
    如果有chatgpt批量提问或其它定制化需求,email to me
```